# [0.2.6](https://github.com/seriaati/akasha-py/compare/v0.2.5..v0.2.6) - 2024-10-07

## Continuous Integrations

- Configure create release workflow - ([b995f6e](https://github.com/seriaati/akasha-py/commit/b995f6e9cda716adfc29a309182822cfbdad652f))
- Upate create-release config - ([1f2ac40](https://github.com/seriaati/akasha-py/commit/1f2ac40c2256351a342cdb0e88dc0dcbc680cb4d))
- Configure workflows - ([7da1c98](https://github.com/seriaati/akasha-py/commit/7da1c98a8ad9f7659af1e9752af9430e49719a28))

## Miscellaneous Chores

- **(deps)** Update dependencies - ([ad9096f](https://github.com/seriaati/akasha-py/commit/ad9096f55fe2f47e50eff9735fc1184abdb58dc3))
- Update renovate config - ([9b77dcb](https://github.com/seriaati/akasha-py/commit/9b77dcb04553f59b0590fd829eb119af7e6e5139))

